@@ -1,6 +1,6 @@
 package Bundle::Bricolage;
 
-our $VERSION = '1.8.3';
+our $VERSION = '1.9.0';
 
 1;
 __END__
@@ -93,6 +93,8 @@ Test::Simple - Basic utilities for writing tests
 
 Test::MockModule 0.04 - Override subroutines in a module for unit testing
 
+Test::File::Contents - Test routines for examining the contents of files
+
 Text::Balanced - Extract delimited text sequences from strings
 
 XML::Parser 2.34 - A Perl module for parsing XML documents
@@ -111,17 +113,25 @@ Locale::Maketext - Framework for Localization in Perl
 
 Test::Class - xUnit/JUnit style Test Suite System
 
-HTTP::BrowserDetect
+HTTP::BrowserDetect - Determine the Web browser, version, and platform from an HTTP user agent string
 
-Safe 2.09
+Params::CallbackRequest 1.10 - Functional and object-oriented callback architecture
 
-Params::CallbackRequest 1.10
+MasonX::Interp::WithCallbacks 1.10 - Mason callback support via Params::CallbackRequest
 
-MasonX::Interp::WithCallbacks 1.10
+Safe 2.09 - Compile and execute code in restricted compartments
+
+DateTime - Date and time objects
+
+DateTime::TimeZone - Time zone object base class and factory
+
+Term::ReadPassword - Prompt for passwords without echoing to the terminal
+
+Data::UUID - Generate globally/universally unique identifiers (GUIDs/UUIDs)
 
 =head1 AUTHOR
 
-David Wheeler <david@wheeler.net>
+David Wheeler <david@kineticode.com>
 
 =head1 SEE ALSO
 
@@ -132,7 +142,7 @@ optional in Bricolage.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2004, David Wheeler. All Rights Reserved.
+Copyright (c) 2002-2005, David Wheeler. All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
